@@ -21,7 +21,7 @@
 ===============================================================================
 """
 
-VERSION = '1.0.3'
+VERSION = '1.0.4'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = """
@@ -58,5 +58,8 @@ First started in 2009.
   
 - 1.0.3, 2017-10-18.
   Several small changes for CamCOPS.
+  
+- 1.0.4, 2017-10-20.
+  Similarly.
 
 """
